@@ -17,6 +17,8 @@ import sys
 import time
 import random
 import inspect
+import builtins
+import operator
 import functools
 import tempfile
 import threading
@@ -1619,13 +1621,53 @@ def ordered(tests):
         human_sort(tests, key=lambda test: test.__name__)
     return tests
 
-def loads(name, *types, package=None, frame=None):
+class has:
+    """Class that contains filters to filter tests
+    by their parameters such as tags.
+    """
+    class Filter:
+        def __init__(self, _op=None):
+            self._op = _op
+
+        def __call__(self, test):
+            if self._op:
+                return self._op(test)
+            return True
+
+        def __or__(self, other):
+            def op(test):
+                return operator.or_(self(test), other(test))
+            return has.Filter(_op=op)
+
+        def __and__(self, other):
+            def op(test):
+                return operator.and_(self(test), other(test))
+            return has.Filter(_op=op)
+
+        def __invert__(self):
+            def op(test):
+                return operator.not_(self(test))
+            return has.Filter(_op=op)
+
+    class tag(Filter):
+        """Tag filter.
+
+        :param name: name
+        """
+        def __init__(self, name):
+            self.name = name
+
+        def __call__(self, test):
+            return self.name in getattr(test, "tags", set())
+
+def loads(name, *types, package=None, frame=None, filter=None):
     """Load multiple tests from module.
 
     :param name: module name or module
     :param *types: test types (Step, Test, Scenario, Suite, Feature, or Module), default: all
     :param package: package name if module name is relative (optional)
     :param frame: caller frame if module name is not specified (optional)
+    :param filter: filter function
     :return: list of tests
     """
     if name is None or name == ".":
@@ -1643,4 +1685,9 @@ def loads(name, *types, package=None, frame=None):
                 return True
             return member.type in types
 
-    return ordered([test for name, test in inspect.getmembers(module, is_type)])
+    tests = ordered([test for name, test in inspect.getmembers(module, is_type)])
+    
+    if filter:
+        return builtins.filter(filter, tests)
+    
+    return tests
